"use strict";
/**
 * A simple and forgiving chart plotting library for JavaScript and TypeScript.
 *
 * @example
 *
 * ```javascript
 * const data = [10, 30, 15, 45]; // Array of numbers.
 * plot(data)
 *      .renderImage("./myplot.png"); // Need &commat;plotex/render-image installed for this.
 * ```
 *
 * @example
 *
 * ```javascript
 * const htmlElement = ...; // An element in the DOM.
 * const data = [10, 30, 15, 45]; // Array of numbers.
 * plot(data)
 *      .renderDOM(htmlElement); // Need &commat;plotex/render-dom installed for this.
 * ```
 * @packageDocumentation
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.plot = void 0;
var plot_api_1 = require("./plot-api");
var serialize_1 = require("./serialize");
__exportStar(require("@plotex/serialization"), exports);
__exportStar(require("@plotex/chart-def"), exports);
/**
 * Create a plot from regular JavaScript data.
 *
 * @param input - The data to plot. Can be an array of numbers or an array objects where the fields in the objects specify the data series.
 * @param plotDef - Optional configuration to control the plot.
 * @param axisMap - Optional configuration that maps data series to axis'.
 *
 * @returns A plot API object that is used to further configure the plot, serialize it or render it to an image.
 *
 * @example
 *
 * ```javascript
 * const data = [10, 30, 15, 45]; // Array of numbers.
 * plot(data)
 *      .renderImage("./myplot.png"); // Need &commat;plotex/render-image installed for this.
 * ```
 *
 * @example
 *
 * ```javascript
 * const data = [ // Array of JS objects to specify multiple data series.
 *  { A: 10, B: 50 },
 *  { A: 30, B: 45, },
 *  { A: 15, B: 60 },
 *  { A: 45, B: 65 }
 * ];
 * plot(data)
 *      .renderImage("./myplot.png"); // Need &commat;plotex/render-image installed for this.
 * ```
 *
 * @example
 *
 * ```javascript
 * const data = {
 *      A: [10, 30, 15, 45],
 *      B: [50, 45, 60, 65]
 * };
 * plot(data)
 *      .renderImage("./myplot.png"); // Need &commat;plotex/render-image installed for this.
 * ```
 */
function plot(input, plotDef, axisMap) {
    var _a = serialize_1.serializeInput(input), serializedData = _a[0], plotDefaults = _a[1];
    return new plot_api_1.PlotAPI(serializedData, plotDef || {}, axisMap || {}, plotDefaults);
}
exports.plot = plot;
//# sourceMappingURL=index.js.map